::cisco::eem::event_register_syslog occurs 1 pattern .*%DHCP-6-ADDRESS_ASSIGN.* maxrun 40 queue_priority high

# _________________________________________________________________________#
# |                                                                       |#
# | hamar_dhcp.tcl                                                        |#
# |                                                                       |#
# | by: David Lin                                                         |#
# |  2009, Cisco Systems, Inc.                                           |#
# |                                                                       |#
# | Version 01.0 11/11/2009                                               |#
# |_______________________________________________________________________|#



#------------------- Namespace imports -----------------

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*


#-------------------   " cli open"   -------------------

if [catch {cli_open} result] {
  error $result $errorInfo
} else {
  array set cli $result
}

#------------------   Enter config mode   ---------------
if [catch {cli_exec $cli(fd) "enable"} result] {
    error $result $errorInfo
  }

if [catch {cli_exec $cli(fd) "config t"} result] {
    error $result $errorInfo
}


#----------------------- "Show dhcp lease" ----------------

if [catch {cli_exec $cli(fd) "do show dhcp lease | include default-gateway"} result] {
    error $result $errorInfo
  }
  set show_dhcp_lease $result


#----------------------- Assume primary path is available  ----------------

if [catch {cli_exec $cli(fd) "event manager environment hamar_pri_ipsla 1"} result] {
    error $result $errorInfo
}


#----------------------- Fetch DHCP default gateway from 'show dhcp lease'  ------------ 

action_syslog msg "Fetching DHCP default gateway ..."

set default_gw ""
regexp {.*Temp default\-gateway addr\: ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)} $show_dhcp_lease match default_gw


#----------------------- Set hamar_pri_gwip environment variable to DHCP default gateway ----------------

if [catch {cli_exec $cli(fd) "event manager environment hamar_pri_gwip $default_gw"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $default_gw"} result] {
    error $result $errorInfo
}

action_syslog msg "Env variable 'hamar_pri_gwip' successfully set to DHCP default gateway $default_gw"


#----------------------- Monitor primary default gateway ----------------

  if [catch {cli_exec $cli(fd) "no ip sla 1"} result] {
    error $result $errorInfo
  }

  if [catch {cli_exec $cli(fd) "ip sla 1"} result] {
    error $result $errorInfo
  }

  if [catch {cli_exec $cli(fd) "icmp-echo $default_gw source-interface $hamar_pri_int"} result] {
    error $result $errorInfo
  }

  if [catch {cli_exec $cli(fd) "timeout 100"} result] {
    error $result $errorInfo
  }

  if [catch {cli_exec $cli(fd) "frequency 3"} result] {
    error $result $errorInfo
  }

  if [catch {cli_exec $cli(fd) "exit"} result] {
    error $result $errorInfo
  }

  if [catch {cli_exec $cli(fd) "ip sla schedule 1 life forever start-time now"} result] {
    error $result $errorInfo
  }

action_syslog msg "IP SLA (1) monitoring $default_gw (icmp-echo)" 


#--------------------- cli close ------------------------

  cli_close $cli(fd) $cli(tty_id)

# eeeeeeeeeeeeeeeeeeeeeeeeeeee    End of hamar_dhcp.tcl eeeeeeeeeeeeeeeeeeeeee 
