::cisco::eem::event_register_syslog pattern "%SYS-5-RESTART" maxrun 120

# _________________________________________________________________________#
# |                                                                       |#
# | hamar_init.tcl                                                        |#
# |                                                                       |#
# | by: David Lin                                                         |#
# |  2009, Cisco Systems, Inc.                                           |#
# |                                                                       |#
# | Version 01.0 11/11/2009                                               |#
# |_______________________________________________________________________|#
 


#-----------   Env var sanity check    -------------

if {![info exists hamar_pri_int]} {
    set result "EEM Policy Error: variable hamar_pri_int has not been set"
    error $result $errorInfo
}

if {![info exists hamar_sec_int]} {
    set result "EEM Policy Error: variable hamar_sec_int has not been set"
    error $result $errorInfo
}

if {![info exists hamar_tertiary_int]} {
    set result "EEM Policy Error: variable hamar_tertiary_int has not been set"
    error $result $errorInfo
}

if {![info exists hamar_sec_gwip]} {
    set result "EEM Policy Error: variable hamar_sec_gwip has not been set"
    error $result $errorInfo
}

if {![info exists hamar_tertiary_gwip]} {
    set result "EEM Policy Error: variable hamar_tertiary_gwip has not been set"
    error $result $errorInfo
}

#-----------  Namespace imports   ------------

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*
namespace import ::path_check::*


#-------------- Print script execution time  ------------

set time_now [clock format [clock seconds]]
action_syslog msg "Preparing system at $time_now"



#--------  Open CLI  ------- 

if [catch {cli_open} result] {
    error $result $errorInfo
} else {
	array set cli $result
}

if [catch {cli_exec $cli(fd) "enable"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "config t"} result] {
    error $result $errorInfo
}


#-----------   Shut Secondary/Tertiary Paths momentarily   -----------

action_syslog msg "Secondary/Tertiary paths will be shut down momentarily..."

if [catch {cli_exec $cli(fd) "interface $hamar_sec_int"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "shut"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "interface $hamar_tertiary_int"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "shut"} result] {
    error $result $errorInfo
}


#----- Get the time uptime, last restart, image file, last reset reason, and config reg setting

if [catch {cli_exec $cli(fd) "do show version"} result] {
    error $result $errorInfo
}
set cmd_output $result

regexp {.+?System image file is \"(.+?)\"} $cmd_output match loaded_image
regexp {.+?uptime is (.+?)\n} $cmd_output match uptime
regexp {.+?System returned to ROM by (.+?)[\r|\n]} $cmd_output match last_reset_reason
regexp {.+?Configuration register is (.+?)[\r|\n]} $cmd_output match conf_reg


#------------------------  Get all the info about the image   ----------

if [catch {cli_exec $cli(fd) "do show run | include boot"} result] {
    error $result $errorInfo
}
set cmd_output $result
regexp {.*?boot system (.+?)[\r|\n]} $cmd_output match boot_image


#------------------------- Print system uptime info   ----------------

set logmsg ""
append logmsg "System reset due to "  $last_reset_reason ", uptime is " $uptime
action_syslog msg "$logmsg"

#-----------------------  Initialize primary gateway ip address  ----------------

if [catch {cli_exec $cli(fd) "event manager environment hamar_pri_gwip 127.0.0.1"} result] {
    error $result $errorInfo
}

set hamar_pri_gwip 127.0.0.1


#---------------  Initialize interface flap & ipsla flags ---------------

if [catch {cli_exec $cli(fd) "event manager environment hamar_pri_flap 0"} result] {
                error $result $errorInfo
}
if [catch {cli_exec $cli(fd) "event manager environment hamar_sec_flap 0"} result] {
                error $result $errorInfo
}
if [catch {cli_exec $cli(fd) "event manager environment hamar_tertiary_flap 0"} result] {
                error $result $errorInfo
}
if [catch {cli_exec $cli(fd) "event manager environment hamar_pri_ipsla 0"} result] {
                error $result $errorInfo
}
if [catch {cli_exec $cli(fd) "event manager environment hamar_sec_ipsla 0"} result] {
                error $result $errorInfo
}
if [catch {cli_exec $cli(fd) "event manager environment hamar_tertiary_ipsla 0"} result] {
                error $result $errorInfo
}

action_syslog msg "All system flags reset (due to reload)" 


# Remove Gateway of Last Resort (GOLR)

 
if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
                error $result $errorInfo
}

action_syslog msg "GOLR reset (due to reload)" 


#----  Delay before bringing secondary link up (80000 msec recommended) ---
action_syslog msg "Secondary interface delay started ($hamar_sec_delay msec)" 
action_syslog msg "Please wait ..." 
after $hamar_sec_delay

if [catch {cli_exec $cli(fd) "interface $hamar_sec_int"} result] {
                error $result $errorInfo
}
if [catch {cli_exec $cli(fd) "no shut"} result] {
                error $result $errorInfo
}

#---   Delay before bringing tertiary link up (20000 msec recommended)   ---
action_syslog msg "Tertiary interface delay started ($hamar_tertiary_delay msec)" 
action_syslog msg "Please wait ..." 
after $hamar_tertiary_delay

if [catch {cli_exec $cli(fd) "interface $hamar_tertiary_int"} result] {
                error $result $errorInfo
}
if [catch {cli_exec $cli(fd) "no shut"} result] {
                error $result $errorInfo
}


#-------------  Close CLI   -----------
 
if [catch {cli_close $cli(fd) $cli(tty_id)} result] {
    error $result $errorInfo
}

###########   End of hamar_init.tcl 
