# _________________________________________________________________________#
# |                                                                       |#
# | hamar_path_check.tcl                                                  |#
# |                                                                       |#
# | by: David Lin                                                         |#
# |  2009, Cisco Systems, Inc.                                           |#
# |                                                                       |#
# | Version 01.0 11/11/2009                                               |#
# |_______________________________________________________________________|#

namespace eval path_check {
    namespace export Path_Check

proc bin2dec {string} {
    set string [format %032s $string]
    binary scan [binary format B32 $string] I str
    return $str
}


proc Config_Nat {string} {
set junk {}
	if [catch {cli_open} result] {
	  error $result $errorInfo
	} else {
  	  array set cli $result
	}

	if [catch {cli_exec $cli(fd) "enable"} result] {
   	  error $result $errorInfo
	}

	if [catch {cli_exec $cli(fd) "config t"} result] {
   	  error $result $errorInfo
	}
	
	if [catch {cli_exec $cli(fd) "do more $string"} result] {
    	error $result $errorInfo
  	}
  	set more_nat_config $result

	set nat_stuff [split $more_nat_config "\n"]

	foreach nat_commands $nat_stuff {
		if [catch {cli_exec $cli(fd) "$nat_commands"} result] {
	    	error $result $errorInfo
		}
	}
return $junk
}


proc No_Nat {} {
set stuff {}
	if [catch {cli_open} result] {
	  error $result $errorInfo
	} else {
  	  array set cli $result
	}

	if [catch {cli_exec $cli(fd) "enable"} result] {
   	  error $result $errorInfo
	}

	if [catch {cli_exec $cli(fd) "config t"} result] {
   	  error $result $errorInfo
	}
	
	if [catch {cli_exec $cli(fd) "do show run | include ip nat"} result] {
    	error $result $errorInfo
  	}
  	set show_ip_nat $result

	set records [split $show_ip_nat "\n"]

	action_syslog msg "Removing all existing NAT configurations"

	foreach nat $records {
		if [catch {cli_exec $cli(fd) "no $nat"} result] {
	    	error $result $errorInfo
		}
	}
return $stuff
}



proc Path_Check {} {
set result {}

global hamar_pri_int
global hamar_pri_flap
global hamar_pri_ipsla
global hamar_sec_int
global hamar_sec_flap
global hamar_sec_ipsla
global hamar_tertiary_int
global hamar_tertiary_flap
global hamar_tertiary_ipsla
global hamar_pri_gwip
global hamar_sec_gwip
global hamar_tertiary_gwip

#open CLI and enable mode
action_syslog msg "Performing path check"

if [catch {cli_open} result] {
  error $result $errorInfo
} else {
  array set cli $result
}

if [catch {cli_exec $cli(fd) "enable"} result] {
   error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "config t"} result] {
   error $result $errorInfo
}


################################################
#
# Fetch Hash Value
#
# Hash is comprised of:
#   hamar_pri_flap 
#   hamar_pri_ipsla 
#   hamar_sec_flap 
#   hamar_sec_ipsla 
#   hamar_tertiary_flap
#   hamar_tertiary_ipsla 
#
# and represents a 6-bit value [0-63]. 
#
# 
################################################

set hamar_hash $hamar_pri_flap$hamar_pri_ipsla$hamar_sec_flap$hamar_sec_ipsla$hamar_tertiary_flap$hamar_tertiary_ipsla
action_syslog msg "Hash value is $hamar_hash (bin), [bin2dec $hamar_hash] (dec)"


########################################################
#
# Configure Gateway of Last Resort (GOLR) based on hash
#
########################################################

# Set GOLR to primary path
if { [bin2dec $hamar_hash] >= 16 && [bin2dec $hamar_hash] <= 31} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_pri_int $hamar_pri_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_pri_int"
}

if { [bin2dec $hamar_hash] >= 48 && [bin2dec $hamar_hash] <= 51} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_pri_int $hamar_pri_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_pri_int"
}

if { [bin2dec $hamar_hash] >= 56 && [bin2dec $hamar_hash] <= 59} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_pri_int $hamar_pri_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_pri_int"
}



# Set GOLR to secondary path
if { [bin2dec $hamar_hash] >= 4 && [bin2dec $hamar_hash] <= 8} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_sec_int $hamar_sec_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_sec_int"
}

if { [bin2dec $hamar_hash] >= 12 && [bin2dec $hamar_hash] <= 15} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_sec_int $hamar_sec_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_sec_int"
}

if { [bin2dec $hamar_hash] >= 36 && [bin2dec $hamar_hash] <= 39} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_sec_int $hamar_sec_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_sec_int"
}

if { [bin2dec $hamar_hash] >= 44 && [bin2dec $hamar_hash] <= 47} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_sec_int $hamar_sec_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_sec_int"
}

if { [bin2dec $hamar_hash] >= 52 && [bin2dec $hamar_hash] <= 55} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_sec_int $hamar_sec_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_sec_int"
}

if { [bin2dec $hamar_hash] >= 60 && [bin2dec $hamar_hash] <= 63} {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_sec_int $hamar_sec_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_sec_int"
}


# Set GOLR to tertiary path
if { [bin2dec $hamar_hash] == 1 || [bin2dec $hamar_hash] == 3 || [bin2dec $hamar_hash] == 9 || [bin2dec $hamar_hash] == 11 || [bin2dec $hamar_hash] == 33 || [bin2dec $hamar_hash] == 35 || [bin2dec $hamar_hash] == 41 || [bin2dec $hamar_hash] == 43 } {
   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "ip route 0.0.0.0 0.0.0.0 $hamar_tertiary_int $hamar_tertiary_gwip"} result] {
   error $result $errorInfo
   }
   action_syslog msg "GOLR set to $hamar_tertiary_int"
}


# Reset system counters and remove Gateway of Last Resort (GOLR)
if { [bin2dec $hamar_hash] == 0 || [bin2dec $hamar_hash] == 2 || [bin2dec $hamar_hash] == 10 || [bin2dec $hamar_hash] == 32 || [bin2dec $hamar_hash] == 34 || [bin2dec $hamar_hash] == 40 || [bin2dec $hamar_hash] == 42 } {

   if [catch {cli_exec $cli(fd) "event manager environment hamar_pri_flap 0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "event manager environment hamar_sec_flap 0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "event manager environment hamar_tertiary_flap 0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "event manager environment hamar_pri_ipsla 0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "event manager environment hamar_sec_ipsla 0"} result] {
   error $result $errorInfo
   }
   if [catch {cli_exec $cli(fd) "event manager environment hamar_tertiary_ipsla 0"} result] {
   error $result $errorInfo
   }

   if [catch {cli_exec $cli(fd) "no ip route 0.0.0.0 0.0.0.0"} result] {
   error $result $errorInfo
   }

   action_syslog msg "System flags & GOLR reset!"
}


#############################################
#
# Fetch Gateway of Last Resort (GOLR)
#
#############################################

if [catch {cli_exec $cli(fd) "do sh ip route | inc Gateway of last resort is"} result] {
   error $result $errorInfo
}
set gw_last_resort $result

action_syslog msg "$gw_last_resort"
#action_syslog msg "llength of gw_last_resort is = [llength $gw_last_resort]"

if { [llength $gw_last_resort] == 8 } {
action_syslog msg "No alternate paths available"
}
 

#############################################
#
# Fetch GOLR next-hop interface
#
#############################################


if { [llength $gw_last_resort] != 8 } {

#Parse for GOLR next-hop interface
action_syslog msg "Fetching GOLR next-hop interface"

regsub -all {\s+} $gw_last_resort " " iproute_output
regexp {Gateway of last resort is (.+?) to network} $iproute_output match nh_ipaddress


#perform recursive lookup on gateway of last resort ip address
if [catch {cli_exec $cli(fd) "do sh ip route $nh_ipaddress | inc directly connected"} result] {
   error $result $errorInfo
}
set cmd_output $result

#debug info: action_syslog msg "sh ip route nh_ipaddress -> $cmd_output"

#fetch gateway of last resort next-hop interface
regsub -all {\s+} $cmd_output " " cmd_output
regexp {directly connected, via (.*) (.*)} $cmd_output match nh_interface junk_output

action_syslog msg "GOLR next-hop interface is $nh_interface"

} else {

set nh_interface NULL0

}


#############################################
#
# NAT configurations based on best
# path available go here...
#
#############################################

#--- Primary NAT (WiFi) 

if {$nh_interface == "$hamar_pri_int"} {
        No_Nat

	action_syslog msg "Applying primary (WiFi) NAT configs"

            if [catch {cli_exec $cli(fd) "do clear ip nat trans *"} result] {
                error $result $errorInfo
            }

	if [catch {cli_exec $cli(fd) "do more hamar_nat_pri.txt"} result] {
    	error $result $errorInfo
  	}
  	set more_nat_config $result

	set nat_stuff [split $more_nat_config "\n"]

	foreach nat_command $nat_stuff {
		if [catch {cli_exec $cli(fd) "$nat_command"} result] {
	    	error $result $errorInfo
		}
	}

           action_syslog msg "NAT successfully configured tracking $nh_interface"          
    }


#--- Secondary NAT (1st Digital Cell)

if {$nh_interface == "$hamar_sec_int" && $nh_ipaddress == "$hamar_sec_gwip"} {
        No_Nat

	action_syslog msg "Applying secondary (1st Digital Cell) NAT configs"

            if [catch {cli_exec $cli(fd) "do clear ip nat trans *"} result] {
                error $result $errorInfo
            }


	    	if [catch {cli_exec $cli(fd) "do more hamar_nat_sec.txt"} result] {
    	error $result $errorInfo
  	}
  	set more_nat_config $result

	set nat_stuff [split $more_nat_config "\n"]

	foreach nat_command $nat_stuff {
		if [catch {cli_exec $cli(fd) "$nat_command"} result] {
	    	error $result $errorInfo
		}
	}

           action_syslog msg "NAT successfully configured tracking $nh_interface"          
    }



#--- Tertiary NAT (2nd Digital Cell)

if {$nh_interface == "$hamar_tertiary_int" && $nh_ipaddress == "$hamar_tertiary_gwip"} {
        No_Nat

	action_syslog msg "Applying Tertiary (2nd Digital Cell) NAT configs"

            if [catch {cli_exec $cli(fd) "do clear ip nat trans *"} result] {
                error $result $errorInfo
            }

	if [catch {cli_exec $cli(fd) "do more hamar_nat_tertiary.txt"} result] {
    	error $result $errorInfo
  	}
  	set more_nat_config $result

	set nat_stuff [split $more_nat_config "\n"]

	foreach nat_command $nat_stuff {
		if [catch {cli_exec $cli(fd) "$nat_command"} result] {
	    	error $result $errorInfo
		}
	}

           action_syslog msg "NAT successfully configured tracking $nh_interface"          
    }


    action_syslog msg "Path check complete"          
    return $result
}


# eeeeeeeeeeeeeeeeeeeeeeeeeeee    End of Tcl procedure eeeeeeeeeeeeeeeeeeeeee

}
