::cisco::eem::event_register_track 1 state any

# _________________________________________________________________________#
# |                                                                       |#
# | hamar_pri.tcl                                                         |#
# |                                                                       |#
# | by: David Lin                                                         |#
# |  2009, Cisco Systems, Inc.                                           |#
# |                                                                       |#
# | Version 01.1 11/11/2009                                               |#
# |_______________________________________________________________________|#


#---------------- Check for required environment variables -------------

if {![info exists hamar_pri_int]} {
    set result "EEM Policy Error: variable hamar_pri_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_sec_int]} {
    set result "EEM Policy Error: variable hamar_sec_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_tertiary_int]} {
    set result "EEM Policy Error: variable hamar_tertiary_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_sec_gwip]} {
    set result "EEM Policy Error: variable hamar_sec_gwip has not been set"
    error $result $errorInfo
}
if {![info exists hamar_tertiary_gwip]} {
    set result "EEM Policy Error: variable hamar_tertiary_gwip has not been set"
    error $result $errorInfo
}


#---------------- Namespace imports ---------------

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*
namespace import ::path_check::*


#---------------- Save exact execution time for command ----------
set time_now [clock format [clock seconds]]


#---------------- Get event specifics from EEM -----------------

array set arr_eventData [event_reqinfo]
action_syslog msg "Primary path event detected at $time_now , track state = $arr_eventData(track_state)"


#----------------- Open CLI -------------- 

if [catch {cli_open} result] {
    error $result $errorInfo
} else {
	array set cli1 $result
}

if [catch {cli_exec $cli1(fd) "enable"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli1(fd) "config t"} result] {
    error $result $errorInfo
}


#------------------ Set primary ipsla flag ---------

if [catch {cli_exec $cli1(fd) "do show track 1"} result] {
    error $result $errorInfo
}
set cmd_output $result

if [regexp {.*?operation return code: (.+?)[\n\r]} $cmd_output match hamar_pri_ipsla] {
    action_syslog msg "Primary path IP SLA return code is $hamar_pri_ipsla"

    if { $hamar_pri_ipsla == "OK" } {

    set hamar_pri_ipsla 1 	    
    action_syslog msg "hamar_pri_ipsla set to 1 (YES)"

    } else {

    set hamar_pri_ipsla 0	  
    action_syslog msg "hamar_pri_ipsla set to 0 (NO)"

    }

    if [catch {cli_exec $cli1(fd) "event manager environment hamar_pri_ipsla $hamar_pri_ipsla"} result] {
    error $result $errorInfo
    }

    } else {
             action_syslog msg "Error: Primary IP SLA return code unknown"
    }


if {$arr_eventData(track_state) == "down"} {


#------------------ Fetch router uptime at bootup ---------
#
# Example output: 
#
# HUB#sh ver | inc uptime
# HUB uptime is 7 minutes
#
# This output will be used to determine the appropriate setting for the hamar_pri_int_flap flag. 
#
# When the router boots up, we want to prevent this flag from inadvertantly getting
# set to YES in the scenario when DHCP triggers _after_ IP SLA 1 has a chance to reach an UP state
# at bootup and when IP SLA 1 is still waiting for the primary interface to initialize.
#
# If the router has just come up within the last 5 minutes, set hamar_pri_int_flap -> NO
# If the router has been up for much longer,                set hamar_pri_int_flap -> YES


if [catch {cli_exec $cli1(fd) "do sh ver | inc uptime"} result] {
    error $result $errorInfo
}
set cmd_show_ver $result
regsub -all {\s+} $cmd_show_ver " " cmd_show_ver


# Sample syslog output for troubleshooting purposes only:
#
# %HA_EM-6-LOG: clock.tcl: cmd_show_ver is: HUB uptime is 58 minutes HUB(config)#
# %HA_EM-6-LOG: clock.tcl: llength is: 6
#
# action_syslog msg "cmd_show_ver is: $cmd_show_ver"
# action_syslog msg "llength is: [llength $cmd_show_ver]"
# action_syslog msg "minutes is [lindex $cmd_show_ver 3]"


# Set hamar_pri_int_flap to "0" if within $hamar_router_uptime, otherwise set to "1"
# Recommended value for $hamar_router_uptime is 5.

if { [llength $cmd_show_ver] == 6 && [lindex $cmd_show_ver 3] <= $hamar_router_uptime } {
	if [catch {cli_exec $cli1(fd) "event manager environment hamar_pri_flap 0"} result] {
	   }
        action_syslog msg "Interface $hamar_pri_int flapped due to system restart" 
        action_syslog msg "hamar_pri_flap set to 0 (NO)"

        } else {
	if [catch {cli_exec $cli1(fd) "event manager environment hamar_pri_flap 1"} result] {
       	}
        action_syslog msg "Interface $hamar_pri_int flapped" 
        action_syslog msg "hamar_pri_flap set to 1 (YES)"
        }
}


#Path Check

Path_Check


# Close cli
 
if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
    error $result $errorInfo
}


#----------- end of hamar_pri.tcl  --------------------
