::cisco::eem::event_register_track 2 state any

# _________________________________________________________________________#
# |                                                                       |#
# | hamar_sec.tcl                                                         |#
# |                                                                       |#
# | by: David Lin                                                         |#
# |  2009, Cisco Systems, Inc.                                           |#
# |                                                                       |#
# | Version 01.1 11/11/2009                                               |#
# |_______________________________________________________________________|#
# 

#---------------- Check for required environment variables -------------

if {![info exists hamar_pri_int]} {
    set result "EEM Policy Error: variable hamar_pri_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_sec_int]} {
    set result "EEM Policy Error: variable hamar_sec_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_tertiary_int]} {
    set result "EEM Policy Error: variable hamar_tertiary_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_sec_gwip]} {
    set result "EEM Policy Error: variable hamar_sec_gwip has not been set"
    error $result $errorInfo
}
if {![info exists hamar_tertiary_gwip]} {
    set result "EEM Policy Error: variable hamar_tertiary_gwip has not been set"
    error $result $errorInfo
}


#---------------- Namespace imports ---------------

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*
namespace import ::path_check::*


#---------------- Save exact execution time for command ----------
set time_now [clock format [clock seconds]]


#---------------- Get event specifics from EEM -----------------

array set arr_eventData [event_reqinfo]
action_syslog msg "Secondary path event detected at $time_now , track state = $arr_eventData(track_state)"


#----------------- Open CLI -------------- 

if [catch {cli_open} result] {
    error $result $errorInfo
} else {
	array set cli1 $result
}

if [catch {cli_exec $cli1(fd) "enable"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli1(fd) "config t"} result] {
    error $result $errorInfo
}


#------------------ Fetch the track status for secondary path ---------

if [catch {cli_exec $cli1(fd) "do show track 2"} result] {
    error $result $errorInfo
}
set cmd_output $result

if [regexp {.*?operation return code: (.+?)[\n\r]} $cmd_output match hamar_sec_ipsla] {
    action_syslog msg "Secondary path IP SLA return code is $hamar_sec_ipsla"

    if { $hamar_sec_ipsla == "OK" } {

       set hamar_sec_ipsla 1 	    
       action_syslog msg "hamar_sec_ipsla set to 1 (YES)"

    } else {

       set hamar_sec_ipsla 0	 
       set hamar_sec_flap 1  
       action_syslog msg "hamar_sec_ipsla set to 0 (NO)"
       action_syslog msg "hamar_sec_flap set to 1 (YES)"
    }

    if [catch {cli_exec $cli1(fd) "event manager environment hamar_sec_ipsla $hamar_sec_ipsla"} result] {
    error $result $errorInfo
    }

    if [catch {cli_exec $cli1(fd) "event manager environment hamar_sec_flap $hamar_sec_flap"} result] {
    error $result $errorInfo
    }

    } else {
             action_syslog msg "Error: Secondary IP SLA return code unknown"
    }

# Path Check

Path_Check

# Close cli
 
if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
    error $result $errorInfo
}


#----------- end of hamar_sec.tcl  --------------------
