::cisco::eem::event_register_track 3 state any

# _________________________________________________________________________#
# |                                                                       |#
# | hamar_tertiary.tcl                                                    |#
# |                                                                       |#
# | by: David Lin                                                         |#
# |  2009, Cisco Systems, Inc.                                           |#
# |                                                                       |#
# | Version 01.1 11/11/2009                                               |#
# |_______________________________________________________________________|#
# 

#---------------- Check for required environment variables -------------

if {![info exists hamar_pri_int]} {
    set result "EEM Policy Error: variable hamar_pri_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_sec_int]} {
    set result "EEM Policy Error: variable hamar_sec_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_tertiary_int]} {
    set result "EEM Policy Error: variable hamar_tertiary_int has not been set"
    error $result $errorInfo
}
if {![info exists hamar_sec_gwip]} {
    set result "EEM Policy Error: variable hamar_sec_gwip has not been set"
    error $result $errorInfo
}
if {![info exists hamar_tertiary_gwip]} {
    set result "EEM Policy Error: variable hamar_tertiary_gwip has not been set"
    error $result $errorInfo
}


#---------------- Namespace imports ---------------

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*
namespace import ::path_check::*


#---------------- Save exact execution time for command ----------
set time_now [clock format [clock seconds]]


#---------------- Get event specifics from EEM -----------------

array set arr_eventData [event_reqinfo]
action_syslog msg "Tertiary path event detected at $time_now , track state = $arr_eventData(track_state)"


#----------------- Open CLI -------------- 

if [catch {cli_open} result] {
    error $result $errorInfo
} else {
	array set cli1 $result
}

if [catch {cli_exec $cli1(fd) "enable"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli1(fd) "config t"} result] {
    error $result $errorInfo
}


#------------------ Fetch the track status for secondary path ---------

if [catch {cli_exec $cli1(fd) "do show track 3"} result] {
    error $result $errorInfo
}
set cmd_output $result

if [regexp {.*?operation return code: (.+?)[\n\r]} $cmd_output match hamar_tertiary_ipsla] {

    action_syslog msg "Tertiary path IP SLA return code is $hamar_tertiary_ipsla"

    if { $hamar_tertiary_ipsla == "OK" } {
 
       set hamar_tertiary_ipsla 1 	    
       action_syslog msg "hamar_tertiary_ipsla set to 1 (YES)"

    } else {

       set hamar_tertiary_ipsla 0	
       set hamar_tertiary_flap 1   
       action_syslog msg "hamar_tertiary_ipsla set to 0 (NO)"
       action_syslog msg "hamar_tertiary_flap  set to 1 (YES)"

    }


    if [catch {cli_exec $cli1(fd) "event manager environment hamar_tertiary_ipsla $hamar_tertiary_ipsla"} result] {
    error $result $errorInfo
    }

    if [catch {cli_exec $cli1(fd) "event manager environment hamar_tertiary_flap $hamar_tertiary_flap"} result] {
    error $result $errorInfo
    }

    } else {
             action_syslog msg "Error: Tertiary IP SLA return code unknown"
    }

#Path Check

Path_Check

# Close cli
 
if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
    error $result $errorInfo
}


#----------- end of hamar_tertiary.tcl  --------------------
